
# $rcs = ' $Id: Europe.pm,v 2.10 2010-03-31 00:14:05 Martin Exp $ ' ;

=head1 NAME

WWW::Search::Ebay::Europe - search for auctions at European eBay sites

=head1 DESCRIPTION

This is an empty package.  It only exists so that CPAN users can say
"install WWW::Search::Ebay::Europe" and they'll get what they expect.
Well, actually I'm not sure what they expect, but they'll get
something reasonable.

It is also used to control the version number of the distribution.

=head1 AUTHOR

Martin 'Kingpin' Thurn, C<mthurn at cpan.org>, L<http://tinyurl.com/nn67z>.

=head1 LICENSE

This software is released under the same license as perl itself.

=cut

package WWW::Search::Ebay::Europe;

use strict;
use warnings;

our
$VERSION = '2.009';

1;

__END__
